\NeedsTeXFormat{LaTeX2e}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           Options and Classes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrartcl}}

\DeclareOption{ngerman}{
  \PassOptionsToPackage{\CurrentOption}{babel}
  \AtEndOfClass{\RequirePackage{icomma}}
}
\DeclareOption{english}{
  \PassOptionsToPackage{\CurrentOption}{babel}
}

\ProcessOptions\relax

\LoadClass[fontsize=9pt,a5paper]{scrartcl}

\RequirePackage{calc}
\RequirePackage{indentfirst}
\RequirePackage{graphicx}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{svg}
\RequirePackage[autostyle]{csquotes}


\RequirePackage[
    backend=biber,
    style=numeric,
    sortlocale=de_DE,
    natbib=true,
    url=false,
    doi=true,
    eprint=false
]{biblatex}

\RequirePackage{babel}
\RequirePackage{geometry}
\geometry{paperheight=216mm,paperwidth=154mm,tmargin=23mm,bmargin=23mm,lmargin=18mm,rmargin=18mm}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           Title
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\maketitle}{
  
  \newpage

  \begin{flushright}
    \fontsize{9}{10}
    \textrm{Forschungskolloquium Baustatik -- Baupraxis 2025}\\
    \textrm{08.--11.09.2025, Bad Boll}
  \end{flushright}

  
  \begin{center}
    {\fontsize{12}{14}\selectfont
    \bfseries
      \@title
    \par
    }

    \vspace{8pt}

    {\fontsize{9}{10}\selectfont
    \bfseries\@author
    \par
    }

    {\fontsize{9}{10}\selectfont
      \def\and{\\\vspace{2pt}}
    \normalfont\@institute
    \par
    }

 \end{center}
}

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\institute}[1]{\gdef\@institute{#1}}

\newcommand{\heading}[1]{\gdef\@heading{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           Define Layout
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\sectionLevel{1}
\def\sectionIndent{0pt}
\def\sectionSpaceBefore{12pt}
\def\sectionSpaceAfter{4pt}
\def\sectionStyle{\normalsize\bfseries}

\renewcommand{\section}{
  \scr@startsection{section}{1}{0pt}{4pt}%
                {1pt}{\normalsize\bfseries}}%

\def\sectionLevel{2}
\def\sectionIndent{0pt}
\def\sectionSpaceBefore{4pt}
\def\sectionSpaceAfter{0pt}
\def\sectionStyle{\normalsize\bfseries}

\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize\fontsize{9}{10}\selectfont {\normalfont\bfseries #1}: #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize\fontsize{9}{10}\selectfont {\normalfont\bfseries #1}: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\setlength{\abovedisplayskip}{4pt}
\setlength{\belowdisplayskip}{4pt}
\setlength{\parindent}{0mm}
\setlength{\parskip}{4pt}
\setlength{\abovecaptionskip}{2pt}
\setlength{\belowcaptionskip}{-10pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           In Document
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\AtBeginDocument{
  \pagestyle{empty}
  \maketitle
  \let\maketitle\relax
}

\endinput
